decoder

package
v0.27.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DecodeRow

func DecodeRow(row *spanner.Row) ([]string, error)

func FormatConfigWithProto

func FormatConfigWithProto(fds *descriptorpb.FileDescriptorSet, multiline bool) (*spanvalue.FormatConfig, error)

FormatConfigWithProto creates a format configuration for decoding Spanner values, with special handling for PROTO and ENUM types based on the provided protobuf file descriptor set. If fds is nil, it returns a config without custom proto/enum support. The multiline parameter controls the formatting of protobuf messages.

func FormatTypeSimple

func FormatTypeSimple(typ *sppb.Type) string

FormatTypeSimple is format type for headers.

func FormatTypeVerbose

func FormatTypeVerbose(typ *sppb.Type) string

FormatTypeVerbose is format type for DESCRIBE.

Types

This section is empty.

Jump to