Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatConfigWithProto ¶
func FormatConfigWithProto(fds *descriptorpb.FileDescriptorSet, multiline bool) (*spanvalue.FormatConfig, error)
FormatConfigWithProto creates a format configuration for decoding Spanner values, with special handling for PROTO and ENUM types based on the provided protobuf file descriptor set. If fds is nil, it returns a config without custom proto/enum support. The multiline parameter controls the formatting of protobuf messages.
func FormatTypeSimple ¶
FormatTypeSimple is format type for headers.
func FormatTypeVerbose ¶
FormatTypeVerbose is format type for DESCRIBE.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.